#ifndef NT2_INCLUDE_CONSTANTS_INVPI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_INVPI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/invpi.hpp>

#endif
